#
# spec file for package nwg-dock-hyprland
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023-2025 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nwg-dock-hyprland
Version:        0.4.7
Release:        1.1
Summary:        Hyprland application dock
License:        MIT
URL:            https://github.com/nwg-piotr/nwg-dock-hyprland
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  go >= 1.22
BuildRequires:  golang-packaging
BuildRequires:  zstd
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk-layer-shell-0)
## MANUAL BEGIN
Recommends:     nwg-drawer
## MANUAL END

%description
Configurable (w/ command line arguments and css) dock, written in Go, aimed
exclusively at the Hyprland Wayland compositor. It features pinned buttons,
client buttons and the launcher button.

%prep
%autosetup -p1 -a1

%build
## Note build takes around 15 minutes
go build -v \
   -mod=vendor \
   -buildmode=pie

%install
install -d -m 0755 %{buildroot}%{_bindir} %{buildroot}%{_datadir}/%{name}/images
install -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -m 0644 config/style.css %{buildroot}%{_datadir}/%{name}/style.css
cp -ar images/* %{buildroot}%{_datadir}/%{name}/images/

%files
%license LICENSE
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/style.css
%{_datadir}/%{name}/images

%changelog
* Wed Jul  2 2025 malcolmlewis@opensuse.org
- Updated to version 0.4.7:
  * Fix: Class containing substring of another class leads to
    incorrect instances, (gh#nwg-piotr/nwg-dock-hyprland#89).
  * Fix: Remove all styling for default hotspot style (fix hotspot
    styling when using box-shadow on dock),
    (gh#nwg-piotr/nwg-dock-hyprland#92).
  * golang.org/x/sync updated to v0.15.0.
- Updates from version 0.4.6:
  * Added -m flag to allow multiple program instances,
    (gh#nwg-piotr/nwg-dock-hyprland#70).
- Updates from version 0.4.5:
  * Improved search for improper app_id,
    (gh#nwg-piotr/nwg-dock-hyprland#79).
  * nwg-drawer set as the default launcher.
- Updates from version 0.4.4:
  * Adjusted tooltip parsing, (gh#nwg-piotr/nwg-dock-hyprland#73).
* Fri Jan 10 2025 malcolmlewis@opensuse.org
- Updated to version 0.4.3:
  * Added -g flag to iGnore certain class names - ported from
    nwg-dock;
  * Dependencies updated.
- Updates from version 0.4.2:
  * Margins omitted for the hotspot window (autohiDe mode),
    (gh#nwg-piotr/nwg-dock-hyprland#65).
- Updates from version 0.4.1:
  * Added optional ~/.config/nwg-dock-hyprland/hotspot.css file
    support, (gh#nwg-piotr/nwg-dock-hyprland#65).
  * Dependencies updated.
- Updates from version 0.4.0:
  * Switched from the gotk3 library to gtk3,
    (gh#nwg-piotr/nwg-dock-hyprland#66).
- Add build requires for gobject-introspection-1.0.
- General spec file cleanup.
* Fri Nov 29 2024 malcolmlewis@opensuse.org
- Updated to version 0.3.3:
  * Use separate task images (dots) and placement, according to the
    dock position, (gh#nwg-piotr/nwg-dock-hyprland#62).
  * Refresh the dock on item unpinned.
  * Update dependencies.
- Changes from version 0.3.2;
  * Added -p right position flag for left-handed users,
    (gh#nwg-piotr/nwg-dock-hyprland#43).
  * Hotspot layershell namespace renamed to "hotspot", to avoid
    blurring the window together with the dock;
- Changes from version 0.3.1:
  * Added -iw (ignoreWorkspaces) parameter to exclude clients from
    specified workspaces, (gh#nwg-piotr/nwg-dock-hyprland#59).
- Changes from version 0.3.0:
  * Open new instances of apps using middle mouse button,
    (gh#nwg-piotr/nwg-dock-hyprland#51).
  * Add "Close all windows" context menu entry,
    (gh#nwg-piotr/nwg-dock-hyprland#50).
  * Add signals to explicit show and hide window,
    (gh#nwg-piotr/nwg-dock-hyprland#55):
    + use of SIGUSR1 to toggle window visibility deprecated,
    + added sigToggle (SIGRTMIN+1) to toggle window visibility,
    + added sigShow (SIGRTMIN+2) to show the window,
    + added sigHide (SIGRTMIN+3) to hide the window.
- Changes from version 0.2.2:
  * Fixed crash on Hyprland v0.42.0: client.Fullscreen field type
    changed from bool to int, (gh#nwg-piotr/nwg-dock-hyprland#48).
- Changes from version 0.2.1:
  * Fixed, (gh#nwg-piotr/nwg-dock-hyprland#49).
  * gotk3 updated.
- Changes from version 0.2.0:
  * Added -lp flag for the launcher button position,
    (gh#nwg-piotr/nwg-dock-hyprland#46).
- Add image(s) install to spec file.
* Wed Jun 12 2024 malcolmlewis@opensuse.org
- Updated to version 0.1.9:
  + Fixed crash on icons missing from GTK theme,
    (gh#nwg-piotr/nwg-dock-hyprland#25).
  + Fixed XDG_DATA_HOME detection,
    (gh#nwg-piotr/nwg-dock-hyprland#36 and
    gh#nwg-piotr/nwg-dock-hyprlandcloses #35).
  + Added setting namespace for gtk-layer-shell,
    (gh#nwg-piotr/nwg-dock-hyprland#37).
  + Fixed mapping output->Gdk.Monitor on gtk3-1:3.24.42.
- Changes from version 0.1.8:
  + Get ready for Hyprland socket files moved to
    $XDG_RUNTIME_DIR/hypr, (gh#nwg-piotr/nwg-dock-hyprland#30).
  + While searching .desktop files, first look for exact
    'class.desktop' file, (gh#nwg-piotr/nwg-dock-hyprland#31).
- Changes from version 0.1.7:
  + Prevent crash on image not found,
    (gh#nwg-piotr/nwg-dock-hyprland#25 and
    gh#nwg-piotr/nwg-dock-hyprland#24).
  + Use different lock files for various users (ported from
    nwg-dock).
- Changes from version 0.1.6:
  + Fixed nil pointer dereference while creating the fallback icon,
    (gh#nwg-piotr/nwg-dock-hyprland#24).
- Changes from version 0.1.5:
  + Added dispatch bringactivetotop after dispatch focuswindow,
    (gh#nwg-piotr/nwg-dock-hyprland#14).
  + Updated dependencies: gotk3, gotk3-layershell, logrus.
  + Added -ico string argument, to specify name or full path to an
    alternative launcher ICOn,
    (gh#nwg-piotr/nwg-dock-hyprland#15 and
    gh#nwg-piotr/nwg-dock-hyprland#17).
  + Added support for apps on the special workspace,
    (gh#nwg-piotr/nwg-dock-hyprland#13).
  + Fixed searching icons in org.*.desktop files.
- Changes from version 0.1.4:
  + Split appName string by " ", use the 1st part while searching
    the icon name, (gh#nwg-piotr/nwg-dock-hyprland#11).
  + Do not force use of the overlay layer when -d (autohide)
    argument used, (gh#nwg-piotr/nwg-dock-hyprland#12).
- Update build requires on go >= 1.22.
* Mon Jul 17 2023 malcolmlewis@opensuse.org
- Initial build at version 0.1.3.
